#include "tenzo.h"

TENZO::TENZO(byte clkPin, byte dtPin, byte gain = GAIN_64) {
  _clkPin = clkPin;
  _dtPin = dtPin;
  _gain = gain;
  _calib = CALIB;

  pinMode(_clkPin, OUTPUT);
  pinMode(_dtPin, INPUT);
}
  
long TENZO::readRaw(void) {
  while (digitalRead(_dtPin)) {};

  long data = 0;
  for (byte i=0; i<(24+_gain); i++) {
    digitalWrite(_clkPin, HIGH);
    
    if (i < 24) {
      data <<= 1;
      if (digitalRead(_dtPin)) data++; 
    }
    
    digitalWrite(_clkPin, LOW);
  }
    
  data ^= 0x800000;
  
  return data;
}

void TENZO::setGain(byte gain) {
  _gain = gain;
}

float TENZO::setCalib(float Fe) {
  _calib = float(readRaw()-_offset) / Fe;
  
  return _calib;
}

void TENZO::tare(void) {
  _offset = readRaw();
}

float TENZO::read(void) {
  return float(readRaw()-_offset)/_calib;
}
